/* eslint-disable */
import {
  Http, IDictionary, Metadata, Router,
} from '@zeedhi/core';
import {
  AlertService, DateRange, Form, Grid, Modal, ModalService, SelectMultiple, Tabs, Text, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class BillingComparisonController {
  private modalFilter!: Modal;

  private dados: any = [];

  public visibility: boolean = true;

  public visibilityMeasurement: boolean = false;

  get visibleFrame() {
    return !this.visibility;
  }

  public openPreview({ row }: any) {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-billingComparisonDetail');

    this.visibility = false;

    window.localStorage.setItem('ROWDATA', JSON.stringify(row));

    if (row.IDTPFATURA === 'X') {
      this.visibilityMeasurement = true;
    } else {
      setOfTabs.activeTab = 0;
      this.visibilityMeasurement = false;
    }

    this.reloadTabs();
  }

  public backToPageMain() {
    // Router.replace(`/informacoes_parceiros?${row.NRPARCNEGOCIO}`);
    // Router.replace('/billingComparison');
    this.visibility = true;
  }

  public eventFilter({ event }: any) {
    event.preventDefault();
    this.openModal();
  }

  public async openModal() {
    this.modalFilter = await ModalService.createFromJson('/billing/modal/modal-filter-billing', true);
    this.modalFilter.show();
  }

  public closeModal() {
    this.modalFilter.hide();
    this.modalFilter?.destroy();
  }

  public filterGrid() {
    const contract = Metadata.getInstance<SelectMultiple>('select-contracts').value;
    const date = Metadata.getInstance<DateRange>('period-dateRange').value;
    const qtd = Metadata.getInstance<TextInput>('input-qtdParcelas').value;
    const parnegocio = Metadata.getInstance<SelectMultiple>('select-bPartner').value;
    const billingScope = Metadata.getInstance<SelectMultiple>('select-billingScope').value;
    const billingType = Metadata.getInstance<SelectMultiple>('select-billingType').value;
    const form = Metadata.getInstance<Form>('form-filter');

    if (form.validate()) {
      if (date.length <=1 ) {
        this.alertMessage('Preencha corretamente o campo de período. <br> Ex: 01/01/2022 até 01/02/2022', 'error');
      } else  {
        this.mountGrid(contract, date, qtd, parnegocio, billingScope, billingType);
        this.closeModal();
      }
    }
  }

  public alertMessage(message: string, type: string) {
    AlertService.show({
      name: 'basic-alert',
      text: message,
      top: true,
      left: false,
      timeout: 3000,
      color: type,
    });
  }

/*
  public callMountGrid({ component }: any) {
    if (component.component === 'ZdButton') {
      const parc = Metadata.getInstance<Select>('select-businessPartner').value;
      const date = Metadata.getInstance<DateRange>('selectDate-modal-filter-VFxPN').value;

      this.mountGridBusinessPartner(date, parc);
      this.closeModal();
    } else {
      this.mountGridBusinessPartner('', 0);
    }
  }
*/
  public mountGrid(contracts: any, date: any, qtd: number, parnegocio:any, billingScope: any, billingType: any) {
    const grid = Metadata.getInstance<TekGrid>('tekGrid-billingComparison');
    grid.datasource.data = [];

    Http.post('/getBillingComparison', {
      DTINICOMPET: (date === '' || date.length < 1) ? null : date[0],
      DTFINCOMPET: (date === '' || date.length < 2) ? null : date[1],
      NRSEQCONTRATO: (contracts.length <= 0) ? null : contracts,
      QTPARCELAS: qtd,
      NRPARCNEGOCIO: (parnegocio.length <= 0) ? null : parnegocio,
      NRTIPOORCAMENTO: (billingScope.length <= 0) ? null : billingScope,
      IDTPFATURA: (billingType.length <= 0) ? null : billingType,
    }).then((response: IDictionary) => {
      response.data.dataset.grid.forEach((element: IDictionary) => {
        grid.datasource.data.push({
          NRFATURACONT: element.NRFATURACONT,
          NRFATURACONT_COMP: element.NRFATURACONT_COMP,
          NRMEDICAOFATURA: element.NRMEDICAOFATURA,
          NRMEDICAOFATURA_COMP: element.NRMEDICAOFATURA_COMP,
          NRCONTRATOFCT: element.NRCONTRATOFCT,
          NMCONTRATO: element.NMCONTRATO,
          NMTIPOORCAMENTO: element.NMTIPOORCAMENTO,
          IDTPFATURA: element.IDTPFATURA,
          NMFANTASIA: element.NMFANTASIA,
          IDSITUACAOFAT: element.IDSITUACAOFAT,
          PERIODO: element.PERIODO,
          PERIODO_COMP: element.PERIODO_COMP,
          VRTOTAL: element.VRTOTAL,
          VRTOTAL_COMP: element.VRTOTAL_COMP,
          VRPERCDIFERENCA: element.VRPERCDIFERENCA,
          VRDIFERENCA: element.VRDIFERENCA,
        });
      });
    });
  }

  public changeMaxWidth({ component }: any) {
    component.columns[6].maxWidth = '250px';
    component.columns[6].overflow = 'wrap';
    component.columns[7].maxWidth = '200px';
    component.columns[7].overflow = 'wrap';
    component.columns[8].maxWidth = '250px';
    component.columns[8].overflow = 'wrap';
  }

  public onMountedHeaderBilling() {
    const data: any = JSON.parse(<string>window.localStorage.getItem('ROWDATA'));
    const TIPODEFATURAMENTO = this.traduction(data.IDTPFATURA);
    const SITUACAO = this.traduction(data.IDSITUACAOFAT);

    Metadata.getInstance<Text>('text-NRFATURACONT').text = data.NRFATURACONT;
    Metadata.getInstance<Text>('text-NRFATURACONT_COMP').text = data.NRFATURACONT_COMP;
    Metadata.getInstance<Text>('text-NRMEDICAOFATURA').text = data.NRMEDICAOFATURA;
    Metadata.getInstance<Text>('text-NRMEDICAOFATURA_COMP').text = data.NRMEDICAOFATURA_COMP;

    Metadata.getInstance<Text>('text-CONTRATO-return').text = data.NRCONTRATOFCT;
    Metadata.getInstance<Text>('text-PARCEIRODENEGOCIO-return').text = data.NMFANTASIA;
    Metadata.getInstance<Text>('text-ESCOPODEFATURAMENTO-return').text = data.NMTIPOORCAMENTO;
    Metadata.getInstance<Text>('text-TIPODEFATURAMENTO-return').text = TIPODEFATURAMENTO;
    Metadata.getInstance<Text>('text-SITUACAO-return').text = SITUACAO;


    // window.localStorage.removeItem('ROWDATA');
  }

  public onMountedHeaderCard() {
    const data: any = JSON.parse(<string>window.localStorage.getItem('ROWDATA'));

    Metadata.getInstance<Text>('title-card-firstPeriod').text = `Período: ${data.PERIODO}`;
    Metadata.getInstance<Text>('title-card-secondPeriod').text = `Período: ${data.PERIODO_COMP}`;

    // window.localStorage.removeItem('ROWDATA');
  }

  public onMountedHeaderCardMeasurement() {
    const data: any = JSON.parse(<string>window.localStorage.getItem('ROWDATA'));

    Metadata.getInstance<Text>('title-card-firstPeriod-frameMeasurement').text = `Período: ${data.PERIODO}`;
    Metadata.getInstance<Text>('title-card-secondPeriod-frameMeasurement').text = `Período: ${data.PERIODO_COMP}`;

    // window.localStorage.removeItem('ROWDATA');
  }

  public traduction(value: any) {

    switch (value) {
      case "A":
        return "Periódico (valor de parcela fixo)";
        break;
      case "X":
        return "Periódico (Valor Apurado por Medição)";
        break;
      case "P":
        return "Parcelamento (Quantidade de Parcelas)";
        break;
      case "1":
        return "Pendente";
        break;
      case "2":
        return "Apurada";
        break;
      case "3":
        return "Faturada";
        break;
      case "4":
        return "Anulada";
        break;
      case "5":
        return "Paralisada";
        break;
      case "6":
        return "Parcialmente Apurada";
        break;
      default:
        return value;
        break;
    }
  }

  public reloadTabs() {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-billingComparisonDetail');

    if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-parcel') {
      this.onMountedHeaderBilling();
      this.onMountedHeaderCard();
      this.mountFilterFrameParcelFirstPeriod();
      this.mountFilterFrameParcelSecondPeriod();
    }
    else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-measurement') {
      this.onMountedHeaderCardMeasurement();
      this.mountFilterMeasurementItemsFirstPeriod();
      this.mountFilterMeasurementItemsSecondPeriod();
      this.mountFilterMeasurementVariableFirstPeriod();
      this.mountFilterMeasurementVariableSecondPeriod();
    }
  }

  public mountFilterFrameParcelFirstPeriod() {
    const NRFATURACONT = Metadata.getInstance<Text>('text-NRFATURACONT').text;
    const grid = Metadata.getInstance<Grid>('grid-firstPeriod-frameParcel');

    this.setFilterGrid(grid, NRFATURACONT);
  }

  public mountFilterFrameParcelSecondPeriod() {
    const NRFATURACONT = Metadata.getInstance<Text>('text-NRFATURACONT_COMP').text;
    const grid = Metadata.getInstance<Grid>('grid-secondPeriod-frameParcel');

    this.setFilterGrid(grid, NRFATURACONT);
  }

  // Enviar o parâmetro NR para filtrar a requisição para montar o Grid do Primeiro Período da Tab de Medição
  public mountFilterMeasurementItemsFirstPeriod() {
    const NRMEDICAOFATURA = Metadata.getInstance<Text>('text-NRMEDICAOFATURA').text;
    const grid = Metadata.getInstance<Grid>('Grid-ContractsItems-firstPeriod');

    this.setFilterGrid(grid, NRMEDICAOFATURA);
  }

  public mountFilterMeasurementItemsSecondPeriod() {
    const NRMEDICAOFATURA = Metadata.getInstance<Text>('text-NRMEDICAOFATURA_COMP').text;
    const grid = Metadata.getInstance<Grid>('Grid-ContractsItems-secondPeriod');

    this.setFilterGrid(grid, NRMEDICAOFATURA);
  }

  public mountFilterMeasurementVariableFirstPeriod() {
    const NRMEDICAOFATURA = Metadata.getInstance<Text>('text-NRMEDICAOFATURA').text;
    const grid = Metadata.getInstance<Grid>('Grid-Element/Service-firstPeriod');

    this.setFilterGrid(grid, NRMEDICAOFATURA);
  }

  public mountFilterMeasurementVariableSecondPeriod() {
    const NRMEDICAOFATURA = Metadata.getInstance<Text>('text-NRMEDICAOFATURA_COMP').text;
    const grid = Metadata.getInstance<Grid>('Grid-Element/Service-secondPeriod');

    this.setFilterGrid(grid, NRMEDICAOFATURA);
  }

  public setFilterGrid(grid: any, NR: any) {
    grid.datasource.setFilter({
      NR: NR,
    });
    grid.datasource.get();
  }
}
